@@ -28,8 +28,7 @@ class Oozie(Tier):
         settings              = RDS.get_settings(args.environment, False)
         env_creds             = Knife().get_credentials(args.environment)
         ts                    = self.get_formatted_time()
-        current_cluster_name  = settings["oozie.cluster_name"]
-        new_cluster_name      = self.new_cluster_name(current_cluster_name, ts)
+        new_cluster_name      = self.new_cluster_name(settings["oozie.cluster_name"], ts)
 
         self.start_new_cluster(
             args=args,
@@ -42,8 +41,13 @@ class Oozie(Tier):
         master_dns = self.get_master_dns(new_cluster_name)
         logging.info("master dns = %s" % master_dns)
   
-        logging.info("updating db with info about new cluster") 
-        self.update_settings(args.environment, new_cluster_name, master_dns)
+        logging.info("updating settings in DB") 
+        self.update_settings(
+            env=args.environment,
+            settings=settings,
+            new_cluster_name=new_cluster_name,
+            new_master_dns=master_dns
+        )
 
         logging.info("deleting oozie.cluster_name key from memcache")
         dir_of_this_file = os.path.dirname(os.path.realpath(os.path.abspath(inspect.getfile(inspect.currentframe()))))
@@ -79,11 +83,20 @@ class Oozie(Tier):
             if node_info["alias"] == "master":
                 return node_info["dns_name"]
         
-    def update_settings(self, env, new_cluster_name, master_dns):
+    def update_settings(self, env, settings, new_cluster_name, new_master_dns):
+        prev_cluster_name = settings["oozie.cluster_name"]
         RDS.run_query(env, False, "update settings set value = \"%s\" where var = \"%s\"" % (new_cluster_name, "oozie.cluster_name"))
-        RDS.run_query(env, False, "update settings set value = \"%s\" where var = \"%s\"" % (master_dns, "oozie.dns"))
-        RDS.run_query(env, False, "update settings set value = \"%s\" where var = \"%s\"" % ("%s:9001" % master_dns, "oozie.jobtracker"))
-        RDS.run_query(env, False, "update settings set value = \"%s\" where var = \"%s\"" % ("hdfs://%s:9000" % master_dns, "oozie.hdfs"))
+        RDS.run_query(env, False, "update settings set value = \"%s\" where var = \"%s\"" % (new_master_dns, "oozie.dns"))
+        RDS.run_query(env, False, "update settings set value = \"%s\" where var = \"%s\"" % ("%s:9001" % new_master_dns, "oozie.jobtracker"))
+        RDS.run_query(env, False, "update settings set value = \"%s\" where var = \"%s\"" % ("hdfs://%s:9000" % new_master_dns, "oozie.hdfs"))
+        if settings.has_key("oozie.prev_clusters"):
+            if settings["oozie.prev_clusters"] == "":
+                prev_clusters = settings["oozie.cluster_name"]
+            else:
+                prev_clusters = "%s,%s" % (prev_clusters, prev_cluster_name)
+            RDS.run_query(env, False, "update settings set value = \"%s\" where var = \"%s\"" % (prev_clusters, "oozie.prev_clusters"))
+
+
 
     def start_new_cluster(self, args, env_creds, settings, ts, new_cluster_name):
         hadoop_vars = [
