@@ -70,6 +70,12 @@ class Web(Tier):
                                        action="store_true", help="Login into a zombie node in %s" % (self.tier))
         self.login_parser.set_defaults(func=self.web_login)
 
+        #Zombie
+        self.zombie_parser = self.tier_parser.add_parser("dezombie",
+                                                        help="Convert Zombies to Live nodes on %s tier" % self.tier)
+        self.zombie_parser.set_defaults(func=self.de_zombie)
+
+
         #add new args for deploy_parser
         self.deploy_parser.add_argument("-r", "--no-rolling", dest="rolling",
                                         default=True, action="store_false",
@@ -147,6 +153,13 @@ class Web(Tier):
         output = Knife().ssh("screen", args.environment, self.tier, self.get_filter(args))
         print output
 
+    def de_zombie(self, args):
+        base_path = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
+        cmd = ["knife", "exec", base_path + "/../scripts/set_node_attr.rb", args.environment, "shutdown_gracefully",
+               "no", self.tier]
+
+        Fork.check_output(cmd, stderr=None)
+
     def get_elb(self, env):
         creds = Knife().get_credentials(env)
         return creds["lb_name"]
